================================
Zalando Data Lake client library
================================


.. image:: https://img.shields.io/pypi/v/zdatalake.svg
        :target: https://pypi.python.org/pypi/zdatalake

.. image:: https://img.shields.io/travis/zdatalake/zdatalake.svg
        :target: https://travis-ci.org/zdatalake/zdatalake

.. image:: https://readthedocs.org/projects/zdatalake/badge/?version=latest
        :target: https://zdatalake.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/zdatalake/zdatalake/shield.svg
     :target: https://pyup.io/repos/github/zdatalake/zdatalake/
     :alt: Updates



Zalando Data Lake client library helpers and CLI


* Free software: MIT license
* Documentation: https://zdatalake.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
